<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once('../wp-includes/compat.php');
require_once('../wp-includes/functions.php');
require_once('../wp-includes/classes.php');

if (!file_exists('../wp-config-sample.php'))
	wp_die('සමාවෙන්න, මට wp-config-sample.php ගොනුවක් අවශ්‍යයි කටයුත්ත සිදුකරන්න. කරුණාකර ඔබේ වර්ඩ්ප්‍රෙස් ස්ථාපනයෙන් මෙම ගොනුව නැවත ලබාදෙන්න.');

$configFile = file('../wp-config-sample.php');

if ( !is_writable('../'))
	wp_die("සමාවෙන්න, මට මෙම නාමාවලියට ලියන්නට බැහැ. ඔබට මෙම නාමාවලියේ අවසර දීම් වෙනස් කිරීමට සිදුවේවි. නැතිනම් wp-config.php ගොනුව ශ්‍රමිකව සකසන්නට සිදුවේවි.");

// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	wp_die("<p>'wp-config.php' ගොනුව දැනටමත් පවතී. ඔබට මෙම ගොනුවේ සැකසුම් කිසිවක් වෙනස් කිරිමට අවශ්‍ය නම් එය මුලින්ම මකා දමන්න. ඉන්පසු නැවත You may try <a href='install.php'>ස්ථාපනය කර බලන්න</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists('../../wp-config.php') && ! file_exists('../../wp-load.php'))
	wp_die("<p>'wp-config.php' ගොනුව දැනටමත් ඔබේ වර්ඩ්ප්‍රෙස් ස්ථාපනයට එක් තලයක් ඉහළින් පවතී. බට මෙම ගොනුවේ සැකසුම් කිසිවක් වෙනස් කිරිමට අවශ්‍ය නම් එය මුලින්ම මකා දමන්න. ඉන්පසු නැවත You may try <a href='install.php'>ස්ථාපනය කර බලන්න</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Setup Configuration File</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>වර්ඩ්ප්‍රෙස් වෙත සාදරයෙන් පිළිගනිමු! ඇරඹීමට පෙර ඔබේ දත්තගබඩාවේ තොරතුරු කිහිපයක් අවශ්‍යයි. ඉදිරියට යාමට පෙර අවශ්‍ය තොරතුරු පුරවන්න.</p>
<ol>
	<li>දත්තගබඩා නාමය</li>
	<li>දත්තගබඩා පරිශීලක නාමය</li>
	<li>දත්තගබඩා මුරපදය</li>
	<li>දත්තගබඩා ධාරකය (host)</li>
	<li>වගු උපසර්ගය (prefix - ඔබට එක් දත්තගබඩාවක් වර්ඩ්ප්‍රෙස් ස්ථාපන කිහිපයක් කිරීමට අවශ්‍ය නම්) </li>
</ol>
<p><strong>යම් හේතුවක් නිසා ස්වයංක්‍රීය ගොනු නිර්මාණය සිදු නොවූවහොත් බයවෙන්නට එපා. මෙයින් සිදුකෙරෙන්නේ දත්තගබඩා තොරතුරු ගොනුවකට ලිවීම පමණයි. ඔබ කළ යුත්තේ <code>wp-config-sample.php</code> ගොනුව නෝට්පෑඩ් වැනි සකසනයක් මගින් විවෘත කර ඔබේ තොරතුරු පුරවා <code>wp-config.php</code> ලෙස සුරැකීම පමණයි. </strong></p>
<p>මෙම තොරතුරු සාමාන්‍යයෙන් ලබාදෙන්නේ ඔබේ සේවා සපයන්නයි. ඔබ සතුව මෙම තොරතුරු නැතිනම් පළමුවෙන්ම ඒවා ඔවුන් වෙතින් ලබාගන්න.</p>

<p class="step"><a href="setup-config.php?step=1" class="button">හරි යමු!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>පහත ඔබේ දත්තගබඩා සම්බන්ධතා තොරතුරු ඇතුළත් කරන්න. ඔබට මෙම තොරතුරු විශ්වාස නැතිනම් ඔබේ සේවා සපයන්නා අමතන්න.</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">දත්තගබඩා නාමය</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>වර්ඩ්ප්‍රෙස් ධාවනය කළ යුතු දත්තගබඩාවේ නම</td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">පරිහීලක නාමය</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>ඔබේ MySQL පරිශීලක නාමය</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">මුරපදය</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...සහ MySQL මුරපදය.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">දත්තගබඩා ධාරකය</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>අවස්ථා 99% මෙය වෙනස් කිරීමට අවශ්‍ය නොවේවි.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">වගු උපසර්ගය</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>ඔබට එක් දත්තගබඩාවක ස්ථාපන කිහිපයක් සිදුකිරීමට අවශ්‍ය නම් මෙය වෙනස් කරන්න.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Submit" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);

	display_header();
?>
<p>ඔක්කොම හරි කොල්ලෝ! ස්ථාපනයේ මෙතැන කටයුතු අවසානයි. වර්ඩ්ප්‍රෙස් වෙත දැන් ඔබේ දත්තගබඩාව වෙත සම්බන්ධ විය හැකියි. ඔබ සූදානම් නම්&hellip;</p>

<p class="step"><a href="install.php" class="button">ස්ථාපනය කරන්න</a></p>
<?php
	break;
}
?>
</body>
</html>
